//dog whistle JTN 20230320

//20230325	V3.1	minor fix to mouth polygon, eps added

//square model

//print flat on the narrow side
//slowly, using 0.4mm extrusion width with a 0.4 nozzle
//make sure seams are placed well, I suggest one seam at the bottom corner at the inlet end and the other at the edge of the inlet
//if you don't have good cooling, print several at a time to let the fine details time to cool

preview = true;		//set this to false for printable output, to save hit F5, to render the final output hit F6, to export the STL hit F7

$fa=3;
$fs=0.25;
eps=1/128;

il = 20;			//inlet length
iw = 6;				//inlet width
ih = 1.1;			//inlet height
io = -0.5;			//inlet offset
ia = 4.7;			//inlet angle (from Z towards Y)	was for lower pitch models 4.55, adjust until the whistle won't stop when blown hard
is = [0.7,0.3];		//inlet scaling (portion of base form size at the starting end)
ies = [1,0.4];		//inlet scaling towards the mouth									for lower pitch models 0.6

my = 1.5;			// = mouth depth 													for lower pitch models 1
mz = 20;			//mouth z position
mw = 7;				//mouth width  														for lower pith models 7

rl = 5;				//resonance cavity length											for lower pitch models 7,8 or 9 etc.
rw = 7;				//resonance cavity width  											for lower pitch models 7
rh = 3;				//resonance cavity height
ro = 0;				//resonance cavity offset

bd = 10;			//base width	= Body dimensions
bt = bd/2;			//base thickness 
bl = il+rl+1;		//base length
rr = 1;				//rounding radius / chamfer

mt = 3;				//mount thickness
ml = 10;			//mount length
mo = 8;				//carrying strap hole offset
md = 4;				//strap hole diameter
er = 10;			//top edge radius

lr = 1;				//bottom lip radius

p = [[0,0],[0,eps],[5,12],[5,0]];	// mouth side profile (2D)

module base_form(h=bl,s=1) {
	linear_extrude(height=h,scale=s,convexity=5) offset(delta=rr,chamfer=true) offset(delta=-rr,chamfer=true) difference() {
		square([bd,bt],center=true);
	}
}

module whistle() {
	difference() {
		base_form();				
		rotate([-ia,0]) translate([0,io,-0.25]) scale(is) base_form(h=il+0.5,s=ies);							//inlet
		translate([0,my,mz]) rotate([90,0,90]) linear_extrude(height=mw,convexity=5,center=true) polygon(p);	//mouth
		translate([0,ro,rl/2+il]) cube([rw,rh,rl],center=true);													//resonance cavity
		//translate([bd/2,0,bl/2]) cube([bd,bd,bl],center=true);												//uncomment for partial cut-away
	}
	difference() {
		union() {
			translate([0,0,bl]) hull() {																		//neck
				base_form(h=eps);
				translate([0,0,mt]) linear_extrude(height=eps,convexity=5) offset(delta=rr,chamfer=true) offset(delta=-rr,chamfer=true) square([bd,mt],center=true);
			}
			translate([0,0,mt+bl]) intersection() {																//rounded top
				linear_extrude(height=ml,convexity=5) offset(delta=rr,chamfer=true) offset(delta=-rr,chamfer=true) square([bd,mt],center=true);
				rotate([90,0,0]) cylinder(h=mt+1,r=er,center=true);
			}

			intersection() {
				translate([0,bt/2,lr]) rotate([0,90,0]) cylinder(h=bd,r=lr,center=true);						//lip
				rotate([0,0,45]) cube((bd+bt)/2*sqrt(2)-rr/1.207,center=true);
			}		
		}
		translate([0,0,bl+mo]) rotate([90,0,0]) cylinder(h=mt+1,d=md,center=true);								//strap hole
	}
}

if(preview) {
	whistle();
	difference() {
		union() {
			translate([-40,0]) whistle();
			translate([-20,0]) rotate([0,0,90]) whistle();
		}
		translate([-50,0,0]) cube([40,bd+eps,bl+2*mt+ml]);
	}
} else {
	translate([-(bl+mt+ml)/2,0,bd/2]) rotate([0,90,180]) whistle();
}

		

